#
# spec file for package kf6-kimageformats
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define qt6_version 6.7.0

%define rname kimageformats

%if 0%{?suse_version} > 1500
# Fails on Leap 15 with '/usr/include/OpenEXR/ImathVec.h:228:34: error: ISO C++17 does not allow dynamic exception specification'
%define with_exr 1
# Leap 15 doesn't have libjxl >= 0.9.4
%define with_jxl 1
# Not available
%define with_jp2 1
%endif
# Full KF6 version (e.g. 6.9.0)
%{!?_kf6_version: %global _kf6_version %{version}}
# Last major and minor KF6 version (e.g. 6.0)
%{!?_kf6_bugfix_version: %define _kf6_bugfix_version %(echo %{_kf6_version} | awk -F. '{print $1"."$2}')}
%bcond_without released
Name:           kf6-kimageformats
Version:        6.11.0
Release:        1.1
Summary:        Image format plugins for Qt
License:        LGPL-2.1-or-later
URL:            https://www.kde.org
Source:         %{rname}-%{version}.tar.xz
%if %{with released}
Source1:        %{rname}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
BuildRequires:  fdupes
BuildRequires:  kf6-extra-cmake-modules >= %{_kf6_bugfix_version}
%if 0%{?with_exr}
BuildRequires:  openexr-devel
%endif
BuildRequires:  cmake(KF6Archive) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(Qt6Gui) >= %{qt6_version}
BuildRequires:  cmake(Qt6PrintSupport) >= %{qt6_version}
BuildRequires:  cmake(Qt6Test) >= %{qt6_version}
BuildRequires:  cmake(libavif) >= 0.8.2
BuildRequires:  cmake(libheif) >= 1.10.0
%if 0%{?with_jp2}
BuildRequires:  cmake(OpenJPEG)
%endif
%if 0%{?with_jxl}
BuildRequires:  pkgconfig(libjxl) >= 0.9.4
BuildRequires:  pkgconfig(libjxl_cms) >= 0.9.4
BuildRequires:  pkgconfig(libjxl_threads) >= 0.9.4
%endif
BuildRequires:  pkgconfig(libraw) >= 0.20.2
BuildRequires:  pkgconfig(libraw_r) >= 0.20.2
# Also install the Qt image plugins
Requires:       qt6-imageformats >= %{qt6_version}

%description
This framework provides additional image format plugins for QtGui.  As
such it is not required for the compilation of any other software, but
may be a runtime requirement for Qt-based software to support certain
image formats.

%package eps
Summary:        EPS image format plugin for Qt
Requires:       ghostscript

%description eps
This plugin provides support for the EPS document format for QtGui. As
it invokes ghostscript for conversion, it should only be used in trusted
environments.

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
%cmake_kf6 -DKIMAGEFORMATS_HEIF:BOOL=TRUE

%kf6_build

%install
%kf6_install

%fdupes %{buildroot}

%files
%license LICENSES/*
%dir %{_kf6_plugindir}/imageformats
%{_kf6_plugindir}/imageformats/kimg_ani.so
%{_kf6_plugindir}/imageformats/kimg_avif.so
%{_kf6_plugindir}/imageformats/kimg_dds.so
%if 0%{?with_exr}
%{_kf6_plugindir}/imageformats/kimg_exr.so
%endif
%{_kf6_plugindir}/imageformats/kimg_hdr.so
%{_kf6_plugindir}/imageformats/kimg_heif.so
%if 0%{?with_jxl}
%{_kf6_plugindir}/imageformats/kimg_jxl.so
%endif
%if 0%{?with_jp2}
%{_kf6_plugindir}/imageformats/kimg_jp2.so
%endif
%{_kf6_plugindir}/imageformats/kimg_kra.so
%{_kf6_plugindir}/imageformats/kimg_ora.so
%{_kf6_plugindir}/imageformats/kimg_pcx.so
%{_kf6_plugindir}/imageformats/kimg_pfm.so
%{_kf6_plugindir}/imageformats/kimg_pic.so
%{_kf6_plugindir}/imageformats/kimg_psd.so
%{_kf6_plugindir}/imageformats/kimg_pxr.so
%{_kf6_plugindir}/imageformats/kimg_qoi.so
%{_kf6_plugindir}/imageformats/kimg_ras.so
%{_kf6_plugindir}/imageformats/kimg_raw.so
%{_kf6_plugindir}/imageformats/kimg_rgb.so
%{_kf6_plugindir}/imageformats/kimg_sct.so
%{_kf6_plugindir}/imageformats/kimg_tga.so
%{_kf6_plugindir}/imageformats/kimg_xcf.so

%files eps
%license LICENSES/*
%dir %{_kf6_plugindir}/imageformats
%{_kf6_plugindir}/imageformats/kimg_eps.so

%changelog
* Sat Feb  8 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.11.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.11.0
- Changes since 6.10.0:
  * Update dependency version to 6.11.0
  * jxl: refactor image saving, native CMYK support
  * Harmonized RAW mime types
  * imageconverter: possibility to set image quality
  * Print more details when writetest fails
  * Fix RAW mime type
  * jxl: refactor image loading
  * Add xml/yaml linting
  * Fix jp2 and hdr plugin json definition
  * Read test: added perceptive fuzziness
  * Modified PCX mime type according to IANA db
  * PSD: Alpha detection improvements
  * PSD: improved option support
  * More metadata read tests
  * Fix use of deprecated methods
  * Metadata and image resolution write test
  * PSD: added support to EXIF metadata
  * JXR: set max XMP size to 4MiB
  * CI: Add linux-qt6-next build
  * DDS: Fix warning in qfloat16 and test failure on PowerPC
  * JXL: Resolution and metadata support via EXIF
  * ani: Read chunk elements one at a time instead all at once (kde#498368)
  * xcf: Return early if seek fails (kde#498381)
  * heif: fix -Wstringop-overread warning
  * jxl: refactor metadata boxes reading
  * RAW: Allow preview loading
  * Add JPEG 2000 support
  * JXL: Fix missing checks for BOXES when parsing animation
  * Try writers with different image sizes
  * Update version to 6.11.0
* Thu Jan  9 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.10.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.10.0
- Changes since 6.9.0:
  * Update dependency version to 6.10.0
  * avif: color profiles improvements
  * Update heif.json
  * HEIF plug-in extended to read AVCI format
  * Readme updated with some clarification
  * DDS: enable plugin by default
  * PSD: Added support to MCH1 and MCH2
  * XCF: Fix OSS Fuzz issue 42527849
  * JXR: Fix loss of HDR data on write for format RGBA16FPx16_Premultiplied
  * DDS: Fix for OSS Fuzz issue 384974505
  * DDS: improved read/write support
  * Read / Write test: added NULL device test
  * DDS: multiple FP improvements
  * PFM: fix error when loading images with comments
  * DDS: fix buffer overflow in readCubeMap
  * Re-added DDS plugin support
  * Update version to 6.10.0
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.9.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.9.0
- Changes since 6.8.0:
  * Update dependency version to 6.9.0
  * jxl: Disable color conversion for animations
  * Improve CMYK writing support
  * Improved write test
  * JXL: load error with some lossless file
  * JXR: jxrlib cannot write HDP and WDP formats
  * heif: avoid crash in heif_image_handle_has_alpha_channel
  * Bump KF and QT versions in ecm_set_disabled_deprecation_versions
  * ci: add Alpine/musl job
  * RGB: avoid to read wrong data
  * JXL: Fix OSS Fuzz issue 377971416
  * Fix compilation warnings
  * JXR: Fix libraries link under FreeBSD
  * JXL: fixed bug when saving grayscale images without color profile
  * PFM: extended to half float format
  * Rename SCT plugin for OSS-FUZZ
  * PCX: support for more formats
  * SCT: added read only support
  * Update version to 6.9.0
* Mon Nov  4 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.8.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.8.0
- Changes since 6.7.0:
  * Update dependency version to 6.8.0
  * TGA: Fixed GrayA image loading error
  * exr: Fix read/write with openexr 3.3 (kde#494571)
  * JXL improvements
  * Update version to 6.8.0
  * JXR: Fixed image reading on sequential devices
  * Simplified read/verify header process
* Mon Oct  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.7.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.7.0
- Changes since 6.6.0:
  * Update dependency version to 6.7.0
  * Fix endianness bug in PCX reader on big endian architectures
  * Fixed read of BGR32 and RGB555 formats
  * FIxed comparison of unsigned expression
  * raw: Getting the image size does not need unpacking
  * Update version to 6.7.0
* Sat Sep  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.6.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.6.0
- Changes since 6.5.0:
  * Update version to 6.6.0
  * XCF: fix crash
  * README update
  * RGB: added options support
  * PCX: added options support
  * Fix crash on malformed files
* Mon Aug  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.5.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.5.0
- Changes since 6.4.0:
  * Update dependency version to 6.5.0
  * JXL: added ImageTransformation option
  * xcf: Fix crash on malformed files
  * pcx: Fix crash in broken files
  * xcf: Fix crash on broken files
  * pcx: fix crash on invalid files
  * pcx: fix crash on invalid files
  * exr: added some usefull attributes
  * pcx: Read 16 color images that are 4bpp and 1 plane
  * Full range HDR support
  * Prepare gitlab for files that are coming int the next commit
  * avif: check return values
  * raw: Fix compiler warning with macro redefinition in Windows
  * Update version to 6.5.0
* Tue Jul  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.4.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.4.0
- Changes since 6.3.0:
  * Fixed wrong plugin options behaviour
  * EXR: Full support for gray image/colorspace
  * Disable JXR plugin due to crashes in JXRLIB
  * PFM: Portable FloatMap read only support
  * PXR: Pixar raster read only support
  * Sanity checks (fuzzer)
  * XCF: fixed wrong composite on Grayscale images
  * Fix compilation
  * Use of metadata macro definitions
  * JXR: added CMYK image to read test
  * XCF: Increased maximum property size
  * JXR support
  * PSD: support native CMYK introduced by Qt 6.8
* Wed Jun  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.3.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.3.0/
- Changes since 6.2.0:
  * Remove explicit maintainer from metainfo
  * Ensure dependencies are provided on Android
* Mon May  6 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.2.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/6.2.0/
- Changes since 6.1.0:
  * Ensure dependencies are provided on Android
  * Fix build with Qt 6.7 on 32 bits
* Fri Apr  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.1.0
  * New feature release
- Changes since 6.0.0:
  * update version for new release
  * Add KF_VERSION & KF_DEP_VERSION variables
  * XCF: testcase update for fixed Qt
  * TGA: added options support
  * More header checks (kde#479612)
* Wed Feb 21 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.0
  * New bugfix release
  * Release announcement not available yet
- Changes since 5.249.0:
  * update version for new release
  * Workaround QTBUG-120614
  * update version for new release
* Wed Jan 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.249.0 (6.0 RC 2):
  * New bugfix release
  * For more details see https://kde.org/announcements/megarelease/6/rc2/
* Mon Jan 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.248.0 (6.0 RC 1)
  * For more details please see:
    https://kde.org/announcements/megarelease/6/rc1/
* Sat May 27 2023 Christophe Marin <christophe@krop.fr>
- Init kf6-kimageformats
